٩(●ᴗ●)۶ Pyxiv
============

**UNDER DEVELOPMENT!**


Todo
----

- Documenting source code
- Writing documentation
- Writing models


Contributing
------------

If you would like to contribute, please check for open issues or open a new issue if you have an idea or a bug.


License
-------

The code in this project is licensed under MIT license.